sci-astronomy/casacore: version bump

Package-Manager: Portage-2.3.6, Repoman-2.3.2
This commit is contained in:
Sébastien Fabbro
2017-07-06 21:29:43 +00:00
parent 7ed8bef039
commit 0d20370b58
11 changed files with 870 additions and 15 deletions

View File

@@ -1,2 +1,2 @@
DIST casacore-2.0.3.tar.gz 7250964 SHA256 44746633113e16f8daabb38c404d2b316b1acfd9304a4df91cb1849d2786d726 SHA512 f434e52cfd2903730c18857126c11eb4fbfe5f7a0555d82f423562d6f41c682262c7bf4775954b16ed60d872a067fc5495ac9aaa17deb9555381436b1a26c741 WHIRLPOOL 8836a27f07f231d676879c69504a32dbd893092a9378ac259698ffe07ee050cedb24dd298b38e4ef86b1c6ea4fac42e9941cd6e9317cf1d404da897c34b6866f
DIST casacore-2.1.0.tar.gz 10173155 SHA256 9c0017e741c1c4b14bc09582867910f750cd76ff2673e0ecd554aa5b2db7acb4 SHA512 ab52bed9ebc5aef79c7b46c963c90fe9db2e7bac82249f99ed0def2496065ae337cdd9359fb9a6c0182fc3faa702f476116bf0edffc54585a3353a43ce6ddd9f WHIRLPOOL cda1fba87a02d5564a3f56c93eaad2c674bc7f8795d4bd56152549174405cd761ef1df5a00d27ebd0d2bf37fe663b17bbd961508607d1a39e1c494795f6fa755
DIST casacore-2.3.0.tar.gz 10326408 SHA256 d8ed5373f5447885be6d3aac72f26cee24a662df5caf4a6cd23e846b79181700 SHA512 48d09e74b0c3885eb9f7bd048f0fd158397f7c6aa2bf9f713af9dbfcf3ce2c5ba0abb9500d3fe1d32977a35e0941b273fbfd8ee69c991a19df264f5f5a28cbb0 WHIRLPOOL c343a6d419e2e39b888141768abba2c7432e58a8751311e70edd856feb71e4ebcd854ea6e47d72505493bc368d022019178b7dd51c7544f725b332b06f521a00

View File

@@ -3,10 +3,9 @@
EAPI=6
# python3 is experimental and only one python is supported
PYTHON_COMPAT=( python2_7 )
PYTHON_COMPAT=( python2_7 python3_{5,6} )
inherit cmake-utils eutils toolchain-funcs fortran-2 python-single-r1
inherit cmake-utils eutils toolchain-funcs fortran-2 python-r1
DESCRIPTION="Core libraries for the Common Astronomy Software Applications"
HOMEPAGE="https://github.com/casacore/casacore"
@@ -22,8 +21,8 @@ RDEPEND="
sci-astronomy/wcslib:0=
sci-libs/cfitsio:0=
sys-libs/readline:0=
virtual/blas
virtual/lapack
virtual/blas:=
virtual/lapack:=
data? ( sci-astronomy/casa-data )
fftw? ( sci-libs/fftw:3.0= )
hdf5? ( sci-libs/hdf5:0= )
@@ -31,24 +30,37 @@ RDEPEND="
${PYTHON_DEPS}
dev-libs/boost:0=[python,${PYTHON_USEDEP}]
dev-python/numpy[${PYTHON_USEDEP}]
)"
)
"
DEPEND="${RDEPEND}
virtual/pkgconfig
doc? ( app-doc/doxygen )
test? ( sci-astronomy/casa-data )"
test? ( sci-astronomy/casa-data )
"
PATCHES=(
"${FILESDIR}"/${PN}-2.3.0-disable-class-and-collaboration-graph-generation.patch
"${FILESDIR}"/${PN}-2.3.0-disable-known-test-failures.patch
"${FILESDIR}"/${PN}-2.3.0-disable-tests-that-require-data-tables.patch
"${FILESDIR}"/${PN}-2.3.0-do-not-install-test-and-demonstration-executables.patch
"${FILESDIR}"/${PN}-2.3.0-fix-FTBFS-tStatisticsUtilities-tLatticeStatistics-and-tLC.patch
"${FILESDIR}"/${PN}-2.3.0-fix-too-small-int-type-for-memory-on-32-bit-machines.patch
"${FILESDIR}"/${PN}-2.3.0-loose-some-tests-tFFTServer-tests.patch
"${FILESDIR}"/${PN}-2.3.0-make-the-check-for-NFS-a-bit-more-portable-BSD.patch
"${FILESDIR}"/${PN}-2.3.0-use-the-correct-symbol-to-detect-Linux-OS.patch
)
pkg_pretend() {
if [[ $(tc-getCC)$ == *gcc* ]] && [[ ${MERGE_TYPE} != binary ]]; then
use c++11 && [[ $(gcc-major-version) -lt 4 ]] || \
( [[ $(gcc-major-version) -eq 4 && $(gcc-minor-version) -lt 7 ]] ) && \
die "You are using gcc but gcc-4.7 or higher is required for C++11"
use openmp && ! tc-has-openmp && \
die "You are using gcc but without OpenMP capabilities that you requested"
( [[ $(gcc-major-version) -eq 4 && $(gcc-minor-version) -lt 7 ]] ) && \
die "You are using gcc but gcc-4.7 or higher is required for C++11"
fi
use openmp && tc-check-openmp
}
pkg_setup() {
use python && python-single-r1_pkg_setup
use python && python-r1_pkg_setup
fortran-2_pkg_setup
}
@@ -78,8 +90,6 @@ src_compile() {
src_install(){
cmake-utils_src_install
# conflict, bug #575726 (gone in version > 2.0.4)
mv "${ED}"usr/bin/show{,casa}table || die
if use doc; then
insinto /usr/share/doc/${PF}
doins -r doc/html

View File

@@ -0,0 +1,43 @@
From: Benda Xu <heroxbd@gentoo.org>
Date: Thu, 11 Sep 2014 18:20:44 +0900
Subject: Disable class and collaboration graph generation
The graphviz-generated class and collaboration graph
occupies 1GB disk space. It is too big to deal with. We turn them
off only to save space. Output image format is specified as svg to
further save space (bug #751947).
---
doxygen.cfg | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/doxygen.cfg b/doxygen.cfg
index 9071e88..94b7ccb 100644
--- a/doxygen.cfg
+++ b/doxygen.cfg
@@ -2103,7 +2103,7 @@ DOT_FONTPATH =
# The default value is: YES.
# This tag requires that the tag HAVE_DOT is set to YES.
-CLASS_GRAPH = YES
+CLASS_GRAPH = NO
# If the COLLABORATION_GRAPH tag is set to YES then doxygen will generate a
# graph for each documented class showing the direct and indirect implementation
@@ -2112,7 +2112,7 @@ CLASS_GRAPH = YES
# The default value is: YES.
# This tag requires that the tag HAVE_DOT is set to YES.
-COLLABORATION_GRAPH = YES
+COLLABORATION_GRAPH = NO
# If the GROUP_GRAPHS tag is set to YES then doxygen will generate a graph for
# groups, showing the direct groups dependencies.
@@ -2215,7 +2215,7 @@ DIRECTORY_GRAPH = NO
# The default value is: png.
# This tag requires that the tag HAVE_DOT is set to YES.
-DOT_IMAGE_FORMAT = png
+DOT_IMAGE_FORMAT = svg
# If DOT_IMAGE_FORMAT is set to svg, then this option can be set to YES to
# enable generation of interactive SVG images that allow zooming and panning.

View File

@@ -0,0 +1,158 @@
From: Ole Streicher <olebole@debian.org>
Date: Fri, 2 Dec 2016 11:11:28 +0100
Subject: Disable known test failures
MIME-Version: 1.0
Content-Type: text/plain; charset="utf-8"
Content-Transfer-Encoding: 8bit
Disable tPath test
sbuild gets HOME variable leaked into the build environment. Debian
uses sbuild as official build farm. Until the cause is pinned down,
this test is disabled.
98/425 Test #101: tPath ...............................***Failed 0.64 sec
1,16d0
< expanded: /home/heroxbd
< expected: /«PKGBUILDDIR»
< absolute: /home/heroxbd
< expected: /«PKGBUILDDIR»
< expanded: /home/heroxbd/test/test2
< expected: /«PKGBUILDDIR»/test/test2
< absolute: /home/heroxbd/test/test2
< expected: /«PKGBUILDDIR»/test/test2
< expanded: /home/heroxbd/test
< expected: /«PKGBUILDDIR»/test
< absolute: /home/heroxbd/test
< expected: /«PKGBUILDDIR»/test
< expanded: /home/heroxbd/test
< expected: /«PKGBUILDDIR»/test
< absolute: /home/heroxbd/test
< expected: /«PKGBUILDDIR»/test
33a18
> OK
FAIL (output not verified): ./tPath
Disable tLSQaips and tLSQFit tests
These tests fail, probably due to the test itself. From
https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=838424#15
I'm not sure what to do about the other two tests that fail on arm64,
"tLSQaips" and "tLSQFit", because those two generate a load of output
text containing floating-point numbers and compare that text with an
expected output. It might not be so easy to make that work on all
architectures. Perhaps one could simply disable those two tests.
Preferably one would still run them, so that we can see what happens
in the logs, but not have the build fail if only those tests fail.
---
casa/IO/test/CMakeLists.txt | 4 ++--
casa/OS/test/CMakeLists.txt | 9 ++++-----
images/Images/test/CMakeLists.txt | 2 +-
lattices/LatticeMath/test/CMakeLists.txt | 2 +-
scimath/Fitting/test/CMakeLists.txt | 4 ++--
tables/TaQL/test/CMakeLists.txt | 4 ++--
6 files changed, 12 insertions(+), 13 deletions(-)
diff --git a/casa/IO/test/CMakeLists.txt b/casa/IO/test/CMakeLists.txt
index 188a6c4..3187b60 100644
--- a/casa/IO/test/CMakeLists.txt
+++ b/casa/IO/test/CMakeLists.txt
@@ -3,9 +3,9 @@ tAipsIOCarray
tAipsIO
tBucketBuffered
tBucketCache
-tBucketFile
+# tBucketFile # https://github.com/casacore/casacore/issues/73
tBucketMapped
-tByteIO
+# tByteIO # https://github.com/casacore/casacore/issues/73
tByteSink
tByteSinkSource
tFilebufIO
diff --git a/casa/OS/test/CMakeLists.txt b/casa/OS/test/CMakeLists.txt
index 520ceed..e5c9ee3 100644
--- a/casa/OS/test/CMakeLists.txt
+++ b/casa/OS/test/CMakeLists.txt
@@ -3,10 +3,10 @@ tCanonicalConversion
tConversion
tConversionPerf
tDataConversion
-tDirectory
+# tDirectory # https://github.com/casacore/casacore/issues/73
tDirectoryIterator
tEnvVar
-tFile
+# tFile # https://github.com/casacore/casacore/issues/73
tHostInfo
tIBMConversion
tLECanonicalConversion
@@ -14,10 +14,9 @@ tMemory
tMemoryTrace
tModcompConversion
tMutex
-tPath
tPrecTimer
-tRegularFile
-tSymLink
+# tRegularFile # https://github.com/casacore/casacore/issues/73
+# tSymLink # https://github.com/casacore/casacore/issues/73
tTime
tTimer
tVAXConversion
diff --git a/images/Images/test/CMakeLists.txt b/images/Images/test/CMakeLists.txt
index 4115c29..6865919 100644
--- a/images/Images/test/CMakeLists.txt
+++ b/images/Images/test/CMakeLists.txt
@@ -69,7 +69,7 @@ tMIRIADImage
# tPagedImage2 # requires geodetic/Observatories
# tRebinImage # requires geodetic/Observatories
tSubImage
-tTempImage
+# tTempImage # https://github.com/casacore/casacore/issues/543
)
foreach (test ${tests})
diff --git a/lattices/LatticeMath/test/CMakeLists.txt b/lattices/LatticeMath/test/CMakeLists.txt
index 47e5c76..23f254f 100644
--- a/lattices/LatticeMath/test/CMakeLists.txt
+++ b/lattices/LatticeMath/test/CMakeLists.txt
@@ -11,7 +11,7 @@ tLatticeHistograms
tLatticeMathUtil
tLatticeSlice1D
tLatticeStatistics
-tLatticeStatsDataProvider
+# tLatticeStatsDataProvider # tries to allocate a 1024*1024*1024 array, which is at least 4GiB
tLatticeTwoPtCorr
# tLattStatsSpecialize
)
diff --git a/scimath/Fitting/test/CMakeLists.txt b/scimath/Fitting/test/CMakeLists.txt
index 35d258f..de69738 100644
--- a/scimath/Fitting/test/CMakeLists.txt
+++ b/scimath/Fitting/test/CMakeLists.txt
@@ -3,8 +3,8 @@ dConstraints
dLSQFit
tFitGaussian
tLinearFitSVD
-tLSQaips
-tLSQFit
+#tLSQaips
+#tLSQFit
tNonLinearFitLM
)
diff --git a/tables/TaQL/test/CMakeLists.txt b/tables/TaQL/test/CMakeLists.txt
index 9cf5223..1fcd338 100644
--- a/tables/TaQL/test/CMakeLists.txt
+++ b/tables/TaQL/test/CMakeLists.txt
@@ -35,8 +35,8 @@ tTaQLNode
# Only test scripts, no test programs.
set (testscripts
ttaql
-tTableGramCretab
-tTableGramAlttab
+# tTableGramCretab # https://github.com/casacore/casacore/issues/541
+# tTableGramAlttab # https://github.com/casacore/casacore/issues/541
tTableGramUpdate
tTableGramMasked
tTableGramNull

View File

@@ -0,0 +1,253 @@
From: Benda Xu <heroxbd@gentoo.org>
Date: Wed, 10 Sep 2014 10:00:43 +0900
Subject: Disable tests that require data tables
The data tables are not available during the build of casacore (yet).
---
coordinates/Coordinates/test/CMakeLists.txt | 12 ++++-----
images/Images/test/CMakeLists.txt | 40 ++++++++++++++---------------
images/Regions/test/CMakeLists.txt | 8 +++---
lattices/LatticeMath/test/CMakeLists.txt | 2 +-
meas/MeasUDF/test/CMakeLists.txt | 2 +-
measures/Measures/test/CMakeLists.txt | 37 ++++++++++++--------------
measures/TableMeasures/test/CMakeLists.txt | 2 +-
ms/MSOper/test/CMakeLists.txt | 6 ++---
ms/MeasurementSets/test/CMakeLists.txt | 2 +-
9 files changed, 53 insertions(+), 58 deletions(-)
diff --git a/coordinates/Coordinates/test/CMakeLists.txt b/coordinates/Coordinates/test/CMakeLists.txt
index bd1c996..248b395 100644
--- a/coordinates/Coordinates/test/CMakeLists.txt
+++ b/coordinates/Coordinates/test/CMakeLists.txt
@@ -1,18 +1,18 @@
set (tests
-dCoordinates
+#dCoordinates # requires geodetic/Observatories
dRemoveAxes
dWorldMap
tCoordinate
-tCoordinateSystem
-tCoordinateUtil
+# tCoordinateSystem # requires geodetic/Observatories
+# tCoordinateUtil # requires geodetic/Observatories
tDirectionCoordinate
-tFrequencyAligner
+# tFrequencyAligner # requires geodetic/Observatories
tGaussianConvert
tLinearCoordinate
tLinearXform
-tObsInfo
+# tObsInfo # requires geodetic/Observatories
tProjection
-tSpectralCoordinate
+# tSpectralCoordinate # requires geodetic/Observatories
tStokesCoordinate
tQualityCoordinate
tTabularCoordinate
diff --git a/images/Images/test/CMakeLists.txt b/images/Images/test/CMakeLists.txt
index 302d798..4115c29 100644
--- a/images/Images/test/CMakeLists.txt
+++ b/images/Images/test/CMakeLists.txt
@@ -35,39 +35,39 @@ endforeach (file)
set (tests
dImageInterface
-dImageStatistics
-dImageSummary
+# dImageStatistics # requires geodetic/Observatories
+# dImageSummary # requires geodetic/Observatories
dPagedImage
tExtendImage
-tFITSErrorImage
+# tFITSErrorImage #
tFITSExtImage
tFITSExtImageII
tFITSImage
tFITSImgParser
-tFITSQualityImage
+# tFITSQualityImage #
tHDF5Image
-tImageAttrHandler
-tImageBeamSet
-tImageConcat
-tImageEmpty
-tImageExpr
-tImageExpr2
-tImageExpr2Gram
-tImageExpr3Gram
+# tImageAttrHandler # requires geodetic/Observatories
+# tImageBeamSet #
+# tImageConcat # needs casacore-data
+# tImageEmpty # requires geodetic/Observatories
+# tImageExpr
+# tImageExpr2
+# tImageExpr2Gram # requires geodetic/Observatories
+# tImageExpr3Gram # requires geodetic/Observatories
tImageExprGram
tImageExprParse
tImageExprParse_addDir
tImageInfo
-tImageProxy
-tImageRegrid
+# tImageProxy
+# tImageRegrid # requires geodetic/Observatories
tImageStatistics
-tImageStatistics2
-tImageUtilities
-tLELSpectralIndex
+# tImageStatistics2 # requires geodetic/Observatories
+# tImageUtilities # requires geodetic/Observatories
+# tLELSpectralIndex # requires geodetic/Observatories
tMIRIADImage
-tPagedImage
-tPagedImage2
-tRebinImage
+# tPagedImage # requires geodetic/Observatories
+# tPagedImage2 # requires geodetic/Observatories
+# tRebinImage # requires geodetic/Observatories
tSubImage
tTempImage
)
diff --git a/images/Regions/test/CMakeLists.txt b/images/Regions/test/CMakeLists.txt
index b94c391..1201346 100644
--- a/images/Regions/test/CMakeLists.txt
+++ b/images/Regions/test/CMakeLists.txt
@@ -9,12 +9,12 @@ foreach (file ${datafiles})
endforeach (file)
set (tests
-tImageRegion
+# tImageRegion
tRegionHandler
-tWCBox
-tWCEllipsoid
+# tWCBox # requires geodetic/Observatories
+# tWCEllipsoid
tWCExtension
-tWCLELMask
+# tWCLELMask # requires geodetic/Observatories
tWCUnion
)
diff --git a/lattices/LatticeMath/test/CMakeLists.txt b/lattices/LatticeMath/test/CMakeLists.txt
index 0d869d5..47e5c76 100644
--- a/lattices/LatticeMath/test/CMakeLists.txt
+++ b/lattices/LatticeMath/test/CMakeLists.txt
@@ -13,7 +13,7 @@ tLatticeSlice1D
tLatticeStatistics
tLatticeStatsDataProvider
tLatticeTwoPtCorr
-tLattStatsSpecialize
+# tLattStatsSpecialize
)
foreach (test ${tests})
diff --git a/meas/MeasUDF/test/CMakeLists.txt b/meas/MeasUDF/test/CMakeLists.txt
index a2ecd9a..b06ee99 100644
--- a/meas/MeasUDF/test/CMakeLists.txt
+++ b/meas/MeasUDF/test/CMakeLists.txt
@@ -1,5 +1,5 @@
set (tests
- tmeas
+# tmeas # requires casacore-data
)
foreach (test ${tests})
diff --git a/measures/Measures/test/CMakeLists.txt b/measures/Measures/test/CMakeLists.txt
index c10a670..261adb1 100644
--- a/measures/Measures/test/CMakeLists.txt
+++ b/measures/Measures/test/CMakeLists.txt
@@ -1,25 +1,25 @@
set (tests
dM1950_2000
-dMeasure
-tEarthField
-tEarthMagneticMachine
-tMBaseline
-tMDirection
-tMEarthMagnetic
-tMFrequency
-tMeasComet
-tMeasIERS
-tMeasJPL
+# dMeasure # geodetic/TAI_UTC
+# tEarthField # geodetic/IGRF
+# tEarthMagneticMachine # geodetic/IGRF
+# tMBaseline # geodetic/IGRF
+# tMDirection
+# tMEarthMagnetic # geodetic/IGRF
+# tMFrequency
+# tMeasComet # ephemerides/VGEO
+# tMeasIERS # geodetic/IERS*
+# tMeasJPL # ephemerides/DE200
tMeasMath
-tMeasure
+# tMeasure # geodetic/TAI_UTC
tMeasureHolder
-tMuvw
-tParAngleMachine
-tQuality
+# tMuvw # geodetic/TAI_UTC
+# tParAngleMachine # geodetic/TAI_UTC
+# tQuality
tRecordTransformable
tStokes
tUVWMachine
-tVelocityMachine
+# tVelocityMachine # geodetic/TAI_UTC
)
foreach (test ${tests})
@@ -29,9 +29,4 @@ foreach (test ${tests})
add_dependencies(check ${test})
endforeach (test)
-if (SOFA_FOUND)
- add_executable (tIAU2000 SofaTest.cc tIAU2000.cc)
- target_link_libraries (tIAU2000 casa_measures ${SOFA_LIBRARY})
- add_test (tIAU2000 ${CMAKE_SOURCE_DIR}/cmake/cmake_assay ./tIAU2000)
- add_dependencies(check tIAU2000)
-endif (SOFA_FOUND)
+# tIAU2000 disabled for missing geodetic/TAI_UTC
diff --git a/measures/TableMeasures/test/CMakeLists.txt b/measures/TableMeasures/test/CMakeLists.txt
index e7c4af1..84e7d6d 100644
--- a/measures/TableMeasures/test/CMakeLists.txt
+++ b/measures/TableMeasures/test/CMakeLists.txt
@@ -1,6 +1,6 @@
set (tests
tTableQuantum
-tTableMeasures
+# tTableMeasures # geodetic/{IERSeop{2000,97},IERSpredict{,2000},TAI_UTC}
dVarRefMdirCol
)
diff --git a/ms/MSOper/test/CMakeLists.txt b/ms/MSOper/test/CMakeLists.txt
index e53aec3..81912cd 100644
--- a/ms/MSOper/test/CMakeLists.txt
+++ b/ms/MSOper/test/CMakeLists.txt
@@ -1,9 +1,9 @@
set (tests
-tMSDerivedValues
-tMSKeys
+# tMSDerivedValues # geodetic/IERSpredict
+# tMSKeys
tMSMetaData
tMSReader
-tMSSummary
+# tMSSummary
)
foreach (test ${tests})
diff --git a/ms/MeasurementSets/test/CMakeLists.txt b/ms/MeasurementSets/test/CMakeLists.txt
index 6e66aad..8150ad4 100644
--- a/ms/MeasurementSets/test/CMakeLists.txt
+++ b/ms/MeasurementSets/test/CMakeLists.txt
@@ -15,7 +15,7 @@ tMeasurementSet
tMSColumns
tMSDataDescBuffer
tMSFieldBuffer
-tMSFieldEphem
+#tMSFieldEphem requires casacore-data
tMSIter
tMSMainBuffer
tMSPolBuffer

View File

@@ -0,0 +1,34 @@
From: Benda Xu <heroxbd@gentoo.org>
Date: Fri, 24 Oct 2014 18:26:54 +0900
Subject: Do not install test and demonstration executables
casacore_{assay,floatcheck} are removed and only used with scons.
measuresdata.csh and ms2uvfits should be included in casacore-doc as examples.
change measuresdata.csh shebang to /usr/bin/tcsh as in Debian.
---
measures/apps/CMakeLists.txt | 2 +-
msfits/apps/CMakeLists.txt | 5 -----
2 files changed, 1 insertion(+), 6 deletions(-)
delete mode 100644 msfits/apps/CMakeLists.txt
diff --git a/measures/apps/CMakeLists.txt b/measures/apps/CMakeLists.txt
index fcf2184..1bbf19f 100644
--- a/measures/apps/CMakeLists.txt
+++ b/measures/apps/CMakeLists.txt
@@ -7,4 +7,4 @@ endforeach(prog findmeastable)
add_executable (measuresdata measuresdata/measuresdata.cc)
target_link_libraries (measuresdata casa_measures ${CASACORE_ARCH_LIBS})
install(TARGETS measuresdata DESTINATION bin)
-install(PROGRAMS measuresdata/measuresdata-update DESTINATION bin)
+install(PROGRAMS DESTINATION bin)
diff --git a/msfits/apps/CMakeLists.txt b/msfits/apps/CMakeLists.txt
deleted file mode 100644
index d2775c8..0000000
--- a/msfits/apps/CMakeLists.txt
+++ /dev/null
@@ -1,5 +0,0 @@
-foreach(prog ms2uvfits)
- add_executable (${prog} ${prog}.cc)
- target_link_libraries (${prog} casa_msfits ${CASACORE_ARCH_LIBS})
- install(TARGETS ${prog} DESTINATION bin)
-endforeach(prog ms2uvfits)

View File

@@ -0,0 +1,162 @@
From: Edmund Grimley Evans <edmund.grimley.evans@gmail.com>
Date: Thu, 1 Jun 2017 22:34:46 +0100
Subject: Fix FTBFS tStatisticsUtilities,
tLatticeStatistics and tLCEllipsoid on arm64
The tests "tStatisticsUtilities" and "tLatticeStatistics" can be made
to pass on arm64 with these adjustments to the expected accuracy.
The test "tLCEllipsoid" seems to be converting ellipses into bitmaps.
I'm guessing it gives different output on amd64 and arm64 because the
real curve passes through a critical point and numerical inaccuracy
puts it on different sides of the point on the two architectures. One
way to fix that might be to use non-round numbers in the parameters so
that the curve does not pass through a critical point. That's what I
tried to do, and with the following changes to the program and the
expected output the test passes on both amd64 and arm64.
---
lattices/LRegions/test/tLCEllipsoid.cc | 4 ++--
lattices/LRegions/test/tLCEllipsoid.out | 24 ++++++++++++------------
lattices/LatticeMath/test/tLatticeStatistics.cc | 4 ++--
scimath/Mathematics/test/tStatisticsUtilities.cc | 2 +-
4 files changed, 17 insertions(+), 17 deletions(-)
diff --git a/lattices/LRegions/test/tLCEllipsoid.cc b/lattices/LRegions/test/tLCEllipsoid.cc
index 9e9ee03..2ff65fa 100644
--- a/lattices/LRegions/test/tLCEllipsoid.cc
+++ b/lattices/LRegions/test/tLCEllipsoid.cc
@@ -212,8 +212,8 @@ int main() {
show(ellipse3);
Float theta = C::pi/4;
- major = 36;
- minor = 16;
+ major = 36.01;
+ minor = 16.01;
xcenter = -1;
ycenter = -1;
LCEllipsoid ellipse4(
diff --git a/lattices/LRegions/test/tLCEllipsoid.out b/lattices/LRegions/test/tLCEllipsoid.out
index 3709155..17d8e87 100644
--- a/lattices/LRegions/test/tLCEllipsoid.out
+++ b/lattices/LRegions/test/tLCEllipsoid.out
@@ -163,7 +163,7 @@
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 29]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 28]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 27]
-0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 26]
+0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 26]
0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 [35, 25]
0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 [35, 24]
0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 [35, 23]
@@ -177,7 +177,7 @@
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 [35, 15]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 [35, 14]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 [35, 13]
-1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 [35, 12]
+1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 [35, 12]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 [35, 11]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 [35, 10]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 [35, 9]
@@ -207,10 +207,10 @@
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 22]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 21]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 20]
-0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 19]
+0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 [35, 19]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 [35, 18]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 [35, 17]
-0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 [35, 16]
+0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 [35, 16]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 [35, 15]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 [35, 14]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 [35, 13]
@@ -222,11 +222,11 @@
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 7]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 6]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 5]
-0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 4]
+0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 4]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 3]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 2]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 1]
-0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 0]
+0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 0]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 35]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 34]
@@ -240,7 +240,7 @@
0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 26]
0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 25]
0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 24]
-0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 23]
+0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 23]
0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 22]
0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 21]
0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 [35, 20]
@@ -254,7 +254,7 @@
0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 [35, 12]
0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 [35, 11]
0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 [35, 10]
-0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 9]
+0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 [35, 9]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 8]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 7]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 6]
@@ -265,11 +265,11 @@
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 1]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 0]
-1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 35]
+1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 35]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 34]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 33]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 32]
-1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 31]
+1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 31]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 30]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 29]
1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 28]
@@ -281,10 +281,10 @@
1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 22]
1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 21]
1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 20]
-1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 19]
+1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 19]
1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 18]
1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 17]
-0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 16]
+1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 16]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 15]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 14]
0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 [35, 13]
diff --git a/lattices/LatticeMath/test/tLatticeStatistics.cc b/lattices/LatticeMath/test/tLatticeStatistics.cc
index 833af91..43e0ae7 100644
--- a/lattices/LatticeMath/test/tLatticeStatistics.cc
+++ b/lattices/LatticeMath/test/tLatticeStatistics.cc
@@ -416,10 +416,10 @@ int main()
AlwaysAssert(sum(pos) == expSum, AipsError);
AlwaysAssert(npts(pos) == expNpts, AipsError);
AlwaysAssert(mean(pos) == expMean, AipsError);
- AlwaysAssert(near(sumsq(pos), expSumSq), AipsError);
+ AlwaysAssert(near(sumsq(pos), expSumSq, 1e-9), AipsError);
AlwaysAssert(near(var(pos), expVar, 1e-10), AipsError);
AlwaysAssert(near(sigma(pos), expSigma, 1e-11), AipsError);
- AlwaysAssert(near(rms(pos), expRMS), AipsError);
+ AlwaysAssert(near(rms(pos), expRMS, 1e-10), AipsError);
AlwaysAssert(mymin(pos) == DComplex(0, 0), AipsError);
AlwaysAssert(mymax(pos) == DComplex(size-1, size-1), AipsError);
diff --git a/scimath/Mathematics/test/tStatisticsUtilities.cc b/scimath/Mathematics/test/tStatisticsUtilities.cc
index 46491c8..c6c443f 100644
--- a/scimath/Mathematics/test/tStatisticsUtilities.cc
+++ b/scimath/Mathematics/test/tStatisticsUtilities.cc
@@ -265,7 +265,7 @@ int main() {
AlwaysAssert(got.rms == expec.rms, AipsError);
AlwaysAssert(near(got.stddev, expec.stddev), AipsError);
AlwaysAssert(near(got.sum, expec.sum), AipsError);
- AlwaysAssert(got.sumsq == expec.sumsq, AipsError);
+ AlwaysAssert(near(got.sumsq, expec.sumsq), AipsError);
AlwaysAssert(near(got.variance, expec.variance), AipsError);
AlwaysAssert(*got.max == *expec.max, AipsError);
AlwaysAssert(*got.min == *expec.min, AipsError);

View File

@@ -0,0 +1,77 @@
From: Ole Streicher <olebole@debian.org>
Date: Fri, 2 Dec 2016 13:16:42 +0100
Subject: Fix too small int type for memory on 32-bit machines
See https://github.com/casacore/casacore/issues/542#issuecomment-264440161
---
casa/OS/HostInfoLinux.h | 22 +++++++++++-----------
1 file changed, 11 insertions(+), 11 deletions(-)
diff --git a/scimath/Mathematics/test/tFFTServer.cc b/scimath/Mathematics/test/tFFTServer.cc
index c211f36..711e5a7 100644
--- a/scimath/Mathematics/test/tFFTServer.cc
+++ b/scimath/Mathematics/test/tFFTServer.cc
@@ -1347,7 +1347,7 @@ public:
}
AlwaysTrue(result.shape().isEqual(expectedResult.shape()),
AipsError);
- AlwaysTrue(allNearAbs(result, expectedResult, epsilon),
+ AlwaysTrue(allNearAbs(result, expectedResult, 2*epsilon),
AipsError);
int out_size = expectedResult.nelements();
diff --git a/scimath/Mathematics/test/tFFTServer2.cc b/scimath/Mathematics/test/tFFTServer2.cc
index a663d50..880bce3 100644
--- a/scimath/Mathematics/test/tFFTServer2.cc
+++ b/scimath/Mathematics/test/tFFTServer2.cc
@@ -1096,7 +1096,7 @@ int main() {
expectedResult(0) = Complex(5,0);
server.fft(result, input, True);
AlwaysAssert(near(result(0), Complex(5,0), FLT_EPSILON), AipsError);
- AlwaysAssert(!near(result(4).imag(), 0.0f, FLT_EPSILON), AipsError);
+ AlwaysAssert(!near(result(4).imag(), 0.0f, 2*FLT_EPSILON), AipsError);
server.fft(reverseTransform, result);
AlwaysAssert(allNearAbs(input, reverseTransform, FLT_EPSILON),
AipsError);

View File

@@ -0,0 +1,60 @@
From: Ole Streicher <olebole@debian.org>
Date: Thu, 24 Nov 2016 14:31:06 +0100
Subject: Make the check for NFS a bit more portable (BSD)
And provide a fallback (f.e. for HURD).However, there is probably no
real use case for that, since also other file systems may be slow or
lack certain features.
---
casa/OS/Directory.cc | 21 +++++++++++++++------
1 file changed, 15 insertions(+), 6 deletions(-)
diff --git a/casa/OS/Directory.cc b/casa/OS/Directory.cc
index 82e6efc..b79ce0f 100644
--- a/casa/OS/Directory.cc
+++ b/casa/OS/Directory.cc
@@ -488,29 +488,38 @@ Vector<String> Directory::shellExpand (const Vector<String>& files, Bool stripPa
return expInNames;
}
-#ifndef __APPLE__
+#if defined(__linux__)
#include <sys/vfs.h>
-#include <linux//nfs_fs.h>
-#else
+#include <linux/nfs_fs.h>
+#elif defined( __APPLE__)
#include <sys/param.h>
#include <sys/mount.h>
#include <sys/vnode.h>
+#elif defined(__FreeBSD_kernel__)
+#include <sys/mount.h>
+#include <sys/param.h>
+#include <stdlib.h>
#endif
Bool Directory::isNFSMounted() const
{
+#if defined(__linux__) || defined(__APPLE__) || defined(__FreeBSD_kernel__)
struct statfs buf;
if (statfs (itsFile.path().expandedName().chars(), &buf) < 0) {
throw (AipsError ("Directory::isNFSMounted error on " +
itsFile.path().expandedName() +
": " + strerror(errno)));
}
-#ifndef __APPLE__
+#endif
+#if defined(__linux__)
return buf.f_type == NFS_SUPER_MAGIC;
-#else
+#elif defined(__APPLE__)
return buf.f_type == VT_NFS;
+#elif defined(__FreeBSD_kernel__)
+ return strcmp (buf.f_fstypename, "nfs") == 0;
+#else
+ return False;
#endif
-
}
} //# NAMESPACE CASACORE - END

View File

@@ -0,0 +1,22 @@
From: Ole Streicher <olebole@debian.org>
Date: Thu, 24 Nov 2016 14:31:06 +0100
Subject: Use the correct symbol to detect Linux OS
Otherwise the compilation fails on powerpc archs
---
casa/aipsenv.h | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/casa/aipsenv.h b/casa/aipsenv.h
index 7e272f0..25912b8 100644
--- a/casa/aipsenv.h
+++ b/casa/aipsenv.h
@@ -130,7 +130,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
#if defined(AIPS_LINUX)
#undef AIPS_LINUX
#endif
-#if defined(__linux)
+#if defined(__linux__)
#define AIPS_LINUX
#endif
diff --git a/casa/OS/HostInfoLinux.h b/casa/OS/HostInfoLinux.h
index f792b71..4edf61d 100644
--- a/casa/OS/HostInfoLinux.h
+++ b/casa/OS/HostInfoLinux.h
@@ -132,13 +132,13 @@ skip_token(const char *p)
// get integer value from v1 cgroup hierarchy of current processes, if
// sub_value is set it returns the entry of a collection identified by value,
// e.g. total_rss from memory.stat
// returns std::numeric_limits<size_t>::max() on error
// note unset cgroup limits usually have intptr_t.max()
// does not support v2 cgroups
-static inline size_t
+static inline uInt64
get_cgroup_limit(std::string group, std::string value, std::string sub_value="")
{
- size_t result = std::numeric_limits<size_t>::max();
+ uInt64 result = std::numeric_limits<uInt64>::max();
// assume common location, technically one needs to search for mounts
const std::string cgroup = std::string("/sys/fs/cgroup/") + group + "/";
@@ -280,12 +280,12 @@ void HostMachineInfo::update_info( )
}
/* can't use more memory than allowed by cgroups, enforced */
- size_t proc_mem_max = get_cgroup_limit("memory", "memory.limit_in_bytes") / 1024;
+ uInt64 proc_mem_max = get_cgroup_limit("memory", "memory.limit_in_bytes") / 1024;
/* usage_in_bytes also includes cache so use memory.stat */
- size_t proc_mem_used = get_cgroup_limit("memory", "memory.stat", "total_rss") / 1024;
+ uInt64 proc_mem_used = get_cgroup_limit("memory", "memory.stat", "total_rss") / 1024;
/* set HostInfo memoryTotal() */
- memory_total = std::min((size_t)sys_mem_total, proc_mem_max);
+ memory_total = std::min((uInt64)sys_mem_total, proc_mem_max);
/* if we have a valid cgroup limit we can determine memoryFree() exactly */
if (proc_mem_max <= sys_mem_total && proc_mem_used <= proc_mem_max) {
@@ -293,7 +293,7 @@ void HostMachineInfo::update_info( )
}
else {
/* no cgroups so we have to assume all memory of host is available */
- memory_free = std::min((size_t)sys_mem_avail, (size_t)memory_total);
+ memory_free = std::min((uInt64)sys_mem_avail, (uInt64)memory_total);
}
memory_used = memory_total - memory_free;
@@ -303,17 +303,17 @@ void HostMachineInfo::update_info( )
cerr << "Error parsing SwapTotal and SwapFree in /proc/meminfo\n";
/* can't use more swap than allowed by cgroups */
- size_t proc_swap_max = get_cgroup_limit("memory", "memory.memsw.limit_in_bytes") / 1024;
- size_t proc_swap_used = get_cgroup_limit("memory", "memory.stat", "total_swap") / 1024;
+ uInt64 proc_swap_max = get_cgroup_limit("memory", "memory.memsw.limit_in_bytes") / 1024;
+ uInt64 proc_swap_used = get_cgroup_limit("memory", "memory.stat", "total_swap") / 1024;
/* limit is mem + swap */
if (proc_mem_max <= sys_mem_total && proc_mem_max <= proc_swap_max) {
proc_swap_max = proc_swap_max - proc_mem_max;
}
/* set swapTotal() */
- swap_total = std::min((size_t)sys_swap_total, proc_swap_max);
+ swap_total = std::min((uInt64)sys_swap_total, proc_swap_max);
- if (proc_swap_max <= (size_t)swap_total && proc_swap_used <= proc_swap_max) {
+ if (proc_swap_max <= (uInt64)swap_total && proc_swap_used <= proc_swap_max) {
swap_free = proc_swap_max - proc_swap_used;
}
else {

View File

@@ -0,0 +1,36 @@
From: Ole Streicher <olebole@debian.org>
Date: Thu, 24 Nov 2016 14:31:06 +0100
Subject: Loose some tests tFFTServer tests
This shall help to compile for mips64el and hppa.
---
scimath/Mathematics/test/tFFTServer.cc | 2 +-
scimath/Mathematics/test/tFFTServer2.cc | 2 +-
2 files changed, 2 insertions(+), 2 deletions(-)
@@ -132,13 +132,13 @@ skip_token(const char *p)
// sub_value is set it returns the entry of a collection identified by value,
// e.g. total_rss from memory.stat
-// returns std::numeric_limits<size_t>::max() on error
+// returns std::numeric_limits<uInt64>::max() on error
// note unset cgroup limits usually have intptr_t.max()
// does not support v2 cgroups